<?php

namespace Drupal\Tests\typogrify\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\filter\FilterPluginCollection;

/**
 * Test the application of the full package of Typogrify and SmartyPants.
 *
 * @group typogrify
 */
class TypogrifySmartyPantsTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['typogrify', 'filter'];

  /**
   * Original example compatibility-test.
   */
  public function testOriginalTypogrifyExample() {

    $before = <<<HTML
<h2>"Jayhawks" & KU fans act extremely obnoxiously</h2>
<p>By J.D. Salinger, Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "Excepteur sint occaecat 'cupidatat' non proident" sunt RFID22 in.... </p>
HTML;
    $after = <<<HTML
<h2>“Jayhawks” <span class="amp">&amp;</span> <span class="caps">KU</span> fans act extremely&nbsp;obnoxiously</h2>
<p>By <span class="caps">J.D.</span> Salinger, Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. “Excepteur sint occaecat ‘cupidatat’ non proident” sunt <span class="caps">RFID22</span>&nbsp;in&#8230;. </p>
HTML;

    $configuration = [
      'settings' => [
        'smartypants_enabled' => 1,
        'smartypants_hyphens' => 2,
        'wrap_ampersand' => 1,
        'widont_enabled' => 1,
        'wrap_abbr' => 0,
        'wrap_caps' => 1,
        'wrap_initial_quotes' => 1,
        'hyphenate_shy' => 0,
        'wrap_numbers' => 0,
        'ligatures' => [],
        'arrows' => [],
        'quotes' => [],
      ],
    ];
    $manager = $this->container->get('plugin.manager.filter');
    $bag = new FilterPluginCollection($manager, []);
    $filter = $bag->get('typogrify');
    $filter->setConfiguration($configuration);
    $result = $filter->process($before, 'en');
    $this->assertEqual($result, $after, t('Original Typogrify example.'));

  }

}
